## CHANGELOG

### 0.5.1 - 2020-02-27

 - Fix rps_per_node calculation

### 0.5.0 - 2019-11-08

 - Add status endpoint

 - Fix caller inputs management

### 0.4.2 - 2019-11-08

 - Fix background caller, but needs gunicorn

### 0.4.1 - 2019-11-07

 - Skip errors on background caller

### 0.4.0 - 2019-11-07

 - Skip errors and count them

### 0.3.0 - 2019-11-07

 - Add support for multiple workers

### 0.2.1 - 2019-11-07

 - Fix requirements

### 0.2.0 - 2019-11-07

 - Add support for distribution calls

### 0.1.0 - 2019-11-04

 - Create first version of the application
